function [ynew,hnew]=rk5(t,h,y,opts,rk,herr)
%% rk5 integrates y forward a time h given [yp]=tendencies(t,h,y,a,g,m,b,Km);
%% Where tendencies is supplied elsewhere.
%% t is time, h is timestep, y(:) are present values.
%%
%% rk5 is at most a Runge-Kutta 5th order scheme, with embedded 
%% lower order schemes from the Cash-Karp parameters.
%%
%% By comparing the higher and lower-order values, a time step
%% is automatically suggested.
%%
%% rkparm.m should be called first to set rk.

k=zeros(6,length(y));
[yp]=tendencies(t+rk.ai(1)*h,h,y,opts);
k(1,:)=h*yp;

for ii=2:6
 [yp]=tendencies(t+rk.ai(ii)*h,h,y+rk.bij(ii,1:ii-1)*k(1:ii-1,:),opts);
 k(ii,:)=h*yp;
end

y5=y+rk.ci(5,:)*k;

%Lower order estimates
y4=y+rk.ci(4,:)*k;
y3=y+rk.ci(3,:)*k;
y2=y+rk.ci(2,:)*k;
y1=y+rk.ci(1,:)*k;

hnew45=h*(herr/max(max(abs(y5-y4)),eps))^0.2;
hnew34=h*(herr/max(abs(y4-y3)))^0.25;
hnew23=h*(herr/max(abs(y3-y2)))^(1/3);
hnew12=h*(herr/max(abs(y2-y1)))^0.5;

hnew=hnew45;  %min([hnew12,hnew23,hnew34,hnew45]);
ynew=y5;
