function [yp]=tendencies(t,h,y,opts)
% function [yp]=tendencies(t,h,y,opts)
% This version of tendencies (dy/dt=yp) 
% provides the tendencies for the damped inertial oscillator
% This is a simple integration program to solve the differential equations:
% d y(1)/dt=y(3)
% d y(2)/dt=y(4)
% d y(3)/dt-2 opts(1) y(4) - opts(2) opts(1)^2 y(1)=-opts(3) y(3)
% d y(4)/dt+2 opts(1) y(3) - opts(2) opts(1)^2 y(2)=-opts(3) y(4)
% For the independent variables y(1-4), given parameters (opts(1-3))
% over time (t).
%
% It is the eqtn for an inertially oscillating particle, 
% in a rotating frame with angular frequency opts(1)
% and drag coefficient opts(3).  
% opts(2)=0 turns off the Centrifugal force (i.e., constant geopotential)
% opts(2)=1 turns on the Centrifugal force (i.e., constant geopotential)
% One could consider y(1) to be the x-position
% One could consider y(2) to be the y-position
% One could consider y(3) to be the x-velocity component
% One could consider y(4) to be the y-velocity component
% of the oscillator, t to be time.
%
% For shorthand, yp is used to denote dy/dt
% For the independent variable y(1-4), given parameters (opts(1-3))
% over time (t).
%

yp(1)=y(3);
yp(2)=y(4);
yp(3)=2*opts(1)*y(4)+opts(2)*opts(1)^2*y(1)-opts(3)*y(3);
yp(4)=-2*opts(1)*y(3)+opts(2)*opts(1)^2*y(2)-opts(3)*y(4);


